@@ -68,18 +68,18 @@ export PKG_BIN_DLLS_REL=1
 export PKG_BIN_LNDIR_REL=1
 export PKG_DEVEL_REL=1
 export PKG_ETC_REL=1
-export PKG_FENC_REL=1
-export PKG_FNTS_REL=1
+export PKG_FENC_REL=2
+export PKG_FNTS_REL=3
   export PKG_F100_REL=${PKG_FNTS_REL}
   export PKG_FCYR_REL=${PKG_FNTS_REL}
-export PKG_FSCL_REL=1
+export PKG_FSCL_REL=2
 export PKG_FSRV_REL=1
 export PKG_LIBS_DATA_REL=1
 export PKG_MAN_PAGES_REL=1
   export PKG_MAN_PAGES_HTML_REL=${PKG_MAN_PAGES_REL}
 export PKG_NEST_REL=1
 export PKG_VFB_REL=1
-export PKG_XWIN_REL=1
+export PKG_XWIN_REL=6
 
 # base
 export PKG_BASE=${PKG}-base
@@ -874,7 +874,6 @@ spkg_xwin() {
     --exclude=xc/programs/Xserver/pandix \
     --exclude=xc/programs/Xserver/panmi \
     --exclude=xc/programs/Xserver/XIE \
-    --exclude=xc/programs/Xserver/XpConfig \
     --exclude=xc/programs/Xserver/Xst
   )
 }
@@ -976,6 +975,11 @@ case $1 in
 			install 2>&1 | tee install.log && strip && \
 			install_local && pkg && install_local && pkg && \
 			spkg ; STATUS=$? ;;
+  pack)	    install 2>&1 | tee install.log && strip && \
+			install_local && pkg && install_local && pkg && \
+			spkg ; STATUS=$? ;;
+  pack-xwin)		build_xwin && install_xwin && strip && install_local && \
+      				pkg_xwin && spkg_xwin ; STATUS=$? ;;
   *)			echo "Error: bad arguments" ; exit 1 ;;
 esac
 exit ${STATUS}
